package com.bonus.canteen.core.user.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.canteen.core.common.annotation.PreventRepeatSubmit;
import com.bonus.system.api.domain.SysAddress;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.user.domain.UserAddr;
import com.bonus.canteen.core.user.service.IUserAddrService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 地址信息Controller
 * 
 * @author xsheng
 * @date 2025-04-14
 */
@Api(tags = "地址信息接口")
@RestController
@RequestMapping("/user_addr")
public class UserAddrController extends BaseController {
    @Autowired
    private IUserAddrService userAddrService;

    /**
     * 查询地址信息列表
     */
    @ApiOperation(value = "查询地址信息列表")
    //@RequiresPermissions("user:addr:list")
    @GetMapping("/list")
    public TableDataInfo list(UserAddr userAddr) {
        startPage();
        List<UserAddr> list = userAddrService.selectUserAddrList(userAddr);
        return getDataTable(list);
    }

    /**
     * 导出地址信息列表
     */
    @ApiOperation(value = "导出地址信息列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("user:addr:export")
    @SysLog(title = "地址信息", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出地址信息")
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserAddr userAddr) {
        List<UserAddr> list = userAddrService.selectUserAddrList(userAddr);
        ExcelUtil<UserAddr> util = new ExcelUtil<UserAddr>(UserAddr.class);
        util.exportExcel(response, list, "地址信息数据");
    }

    /**
     * 获取地址信息详细信息
     */
    @ApiOperation(value = "获取地址信息详细信息")
    //@RequiresPermissions("user:addr:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(userAddrService.selectUserAddrById(id));
    }

    /**
     * 新增地址信息
     */
    @ApiOperation(value = "新增地址信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("user:addr:add")
    @SysLog(title = "地址信息", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增地址信息")
    @PostMapping
    public AjaxResult add(@RequestBody UserAddr userAddr) {
        try {
            return toAjax(userAddrService.insertUserAddr(userAddr));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 修改地址信息
     */
    @ApiOperation(value = "修改地址信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("user:addr:edit")
    @SysLog(title = "地址信息", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改地址信息")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody UserAddr userAddr) {
        try {
            return toAjax(userAddrService.updateUserAddr(userAddr));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 设置默认地址
     */
    @ApiOperation(value = "设置默认地址")
    //@PreventRepeatSubmit
    //@RequiresPermissions("user:addr:edit")
    @SysLog(title = "设置默认地址", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->设置默认地址")
    @PostMapping("/setDefault")
    public AjaxResult setDefault(@RequestBody UserAddr userAddr) {
        try {
            return toAjax(userAddrService.updateUserAddrAsDefault(userAddr));
        } catch (Exception e) {
            return error("系统错误, " + e.getMessage());
        }
    }

    /**
     * 删除地址信息
     */
    @ApiOperation(value = "删除地址信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("user:addr:remove")
    @SysLog(title = "地址信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除地址信息")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(userAddrService.deleteUserAddrByIds(ids));
    }

    /**
     * 删除地址信息
     */
    @ApiOperation(value = "删除地址信息")
    //@PreventRepeatSubmit
    //@RequiresPermissions("user:addr:remove")
    @SysLog(title = "地址信息", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除地址信息")
    @PostMapping("/del")
    public AjaxResult remove(@RequestBody SysAddress sysAddress) {
        return toAjax(userAddrService.deleteUserAddrById(sysAddress.getId()));
    }
}
